@@ -1,6 +1,6 @@
 package App::HasPrereqs;
 
-use 5.010;
+use 5.010001;
 use strict;
 use warnings;
 use Log::Any qw($log);
@@ -14,7 +14,7 @@ require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(has_prereqs);
 
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 $SPEC{has_prereqs} = {
     v => 1.1,
@@ -101,32 +101,27 @@ sub has_prereqs {
 1;
 #ABSTRACT: Check whether your Perl installation has prerequisites in dist.ini
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 App::HasPrereqs - Check whether your Perl installation has prerequisites in dist.ini
 
 =head1 VERSION
 
-version 0.03
+This document describes version 0.04 of App::HasPrereqs (from Perl distribution App-HasPrereqs), released on 2014-07-22.
 
 =head1 SYNOPSIS
 
  # Use via has-prereqs CLI script
 
-=head1 DESCRIPTION
-
-
-This module has L<Rinci> metadata.
-
 =head1 FUNCTIONS
 
 
-None are exported by default, but they are exportable.
-
 =head2 has_prereqs(%args) -> [status, msg, result, meta]
 
 Check whether your Perl installation has prerequisites in dist.ini.
@@ -143,7 +138,32 @@ Add directory to @INC.
 
 Return value:
 
-Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+ (any)
+
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/App-HasPrereqs>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-App-HasPrereqs>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-HasPrereqs>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
 =head1 AUTHOR
 
@@ -151,10 +171,9 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Steven Haryanto.
+This software is copyright (c) 2014 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
